@@ -1,17 +1,17 @@
 /*
- * Copyright (C) 1993-2007 Robert & Jeremy Laine
+ * Copyright (C) 1993-2008 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -100,19 +100,19 @@ CBoatElementWidget::CBoatElementWidget(QWidget *parent)
     iLayout->addWidget( lblFileStatic, 0, 0 );
     lblFile = new QLabel( grpInfo );
     iLayout->addWidget( lblFile, 0, 1 );
-    
+
     lblNameStatic = new QLabel( grpInfo );
     iLayout->addWidget( lblNameStatic, 1, 0 );
     txtName = new QLineEdit( grpInfo );
     iLayout->addWidget( txtName, 1, 1 );
-    
+
     btnReload = new QPushButton(grpInfo);
     iLayout->addWidget( btnReload, 2, 1);
 
     wdgOrigin = new CVector3dWidget(grpInfo);
     iLayout->addWidget(wdgOrigin, 3, 0, 1, 3);
     //iLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 4, 1 );
-    
+
     // add button below frame
     btnUpdate = new QPushButton(this);
     btnRemove = new QPushButton(this);
@@ -123,7 +123,7 @@ CBoatElementWidget::CBoatElementWidget(QWidget *parent)
     layout->addWidget(btnRemove, 1, 0);
     layout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum ), 1, 1 );
     layout->addWidget(btnUpdate, 1, 2);
-    
+
     // pack everything upward
     layout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding ), 2, 0 );
 
@@ -158,8 +158,8 @@ void CBoatElementWidget::languageChange()
 void CBoatElementWidget::setElement(const CBoatElement& newelement)
 {
     element = newelement;
-    lblFile->setText( element.filename );
-    txtName->setText( element.title );
+    lblFile->setText( QString::fromStdString(element.filename) );
+    txtName->setText( QString::fromStdString(element.title) );
     wdgOrigin->setVector( element.origin );
 }
 
@@ -169,21 +169,23 @@ void CBoatElementWidget::setElement(const CBoatElement& newelement)
  */
 void CBoatElementWidget::slotReload()
 {
+    QString filename = QString::fromStdString(element.filename);
+
     try
     {
         switch (element.type)
         {
         case SAILDEF:
-            (CPanelGroup&)element = CSailWorker(CSailDefXmlWriter().read(element.filename)).makeSail();
+            (CPanelGroup&)element = CSailWorker(CSailDefXmlWriter().read(filename)).makeSail();
             break;
         case HULLDEF:
-            (CPanelGroup&)element = CHullWorker(CHullDefXmlWriter().read(element.filename)).makeHull();
+            (CPanelGroup&)element = CHullWorker(CHullDefXmlWriter().read(filename)).makeHull();
             break;
         case RIGDEF:
-            (CPanelGroup&)element = CRigWorker(CRigDefXmlWriter().read(element.filename)).makeRig();
+            (CPanelGroup&)element = CRigWorker(CRigDefXmlWriter().read(filename)).makeRig();
             break;
         case PANELGROUP:
-            (CPanelGroup&)element = CPanelGroupXmlWriter().read(element.filename);
+            (CPanelGroup&)element = CPanelGroupXmlWriter().read(filename);
             break;
         }
         signalUpdate(element);
@@ -209,7 +211,7 @@ void CBoatElementWidget::slotRemove()
  */
 void CBoatElementWidget::slotUpdate()
 {
-    element.title = txtName->text();
+    element.title = txtName->text().toStdString();
     element.origin = wdgOrigin->getVector();
     signalUpdate(element);
 }
@@ -235,7 +237,7 @@ CBoatDefPanel::CBoatDefPanel(QWidget *parent)
  */
 void CBoatDefPanel::languageChange()
 {
-    for ( unsigned int i = 0; i < elementwidget.size(); i++)
+    for (unsigned int i = 0; i < elementwidget.size(); i++)
         elementwidget[i]->languageChange();
 }
 
@@ -248,24 +250,24 @@ void CBoatDefPanel::languageChange()
 void CBoatDefPanel::setDef(const CBoatDef& newdef)
 {
     unsigned int i;
-    for ( i = 0; i < elementwidget.size(); i++)
+    for (i = 0; i < elementwidget.size(); i++)
     {
         tabs->removeTab(i);
         delete elementwidget[i];
     }
 
     def = newdef;
-    elementwidget.resize(def.element.size());
+    elementwidget.resize(def.size());
 
-    for ( i = 0; i < def.element.size(); i++)
+    for (i = 0; i < def.size(); i++)
     {
         elementwidget[i] = new CBoatElementWidget(0);
-        elementwidget[i]->setElement(def.element[i]);
+        elementwidget[i]->setElement(def[i]);
 
         connect(elementwidget[i], SIGNAL(signalRemove()), this, SLOT(slotRemove()));
         connect(elementwidget[i], SIGNAL(signalUpdate(const CBoatElement&)), this, SLOT(slotUpdate(const CBoatElement&)));
 
-        tabs->addTab(elementwidget[i], def.element[i].title);
+        tabs->addTab(elementwidget[i], QString::fromStdString(def[i].title));
     }
 
     if (elementwidget.size() > 0)
@@ -284,7 +286,7 @@ void CBoatDefPanel::slotRemove()
     tabs->removeTab(tabIndex);
     delete elementwidget[tabIndex];
     elementwidget.erase(elementwidget.begin()+tabIndex);
-    def.element.erase(def.element.begin()+tabIndex);
+    def.erase(def.begin()+tabIndex);
     signalUpdate(def);
 }
 
@@ -298,8 +300,8 @@ void CBoatDefPanel::slotUpdate(const CBoatElement& newelement)
 {
     int tabIndex = tabs->currentIndex();
 
-    def.element[tabIndex] = newelement;
-    tabs->setTabText(tabIndex, def.element[tabIndex].title);
+    def[tabIndex] = newelement;
+    tabs->setTabText(tabIndex, QString::fromStdString(def[tabIndex].title));
     signalUpdate(def);
 }
 
