@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2007 Robert & Jeremy Laine
+ * Copyright (C) 1993-2008 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,8 +21,7 @@
 #define SAILDISP_H
 
 #include "panelgroup.h"
-#include <geocpp/geocpp.h>
-#include "disparea.h"
+#include "sailcalc.h"
 
 
 /** A generic display area for a panel group.
@@ -30,7 +29,7 @@
  * @see CSailDispLabel
  * @see CSailDispGL
  */
-class CSailDisp : public CDispArea
+class CSailDisp
 {
 public:
     CSailDisp();
@@ -70,7 +69,13 @@ protected:
     /** Rotated copy of the objects */
     CPanelGroup dispObject;
 
-private:    
+    /** The center of the viewing area, in logical coordinates */
+    CPoint3d center;
+
+    /** The zoom factor for the view */
+    real zoom;
+
+private:
     /** Rotation matrix for the view */
     CMatrix m;
     /** Viewport rectangle, in logical coordinates */
