@@ -1,17 +1,17 @@
 /*
- * Copyright (C) 1993-2007 Robert & Jeremy Laine
+ * Copyright (C) 1993-2008 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -81,9 +81,9 @@ void CSailCarlsonWriter::writePanelHeader(ofstream &out, const CPanel &panel) co
     real xoff =0 , yoff = 0, rtx=0; // position and text rotation from x axis.
     xoff= panel.label.origin.x();
     yoff= panel.label.origin.y();
-    //rtx = atn2(  xoff= panel.label.direction.y(),  xoff= _sail.panel[panel].label.direction.x());
+    //rtx = atn2(  xoff= panel.label.direction.y(),  xoff= _sail[panel].label.direction.x());
 
-    out << "panel, "<< string(panel.label.name.toLocal8Bit()) <<", "<<pencolor<<", "<< xoff<<", "<<yoff<<", "<<rtx<<", "<<htx << CRLF;
+    out << "panel, "<< panel.label.name <<", "<<pencolor<<", "<< xoff<<", "<<yoff<<", "<<rtx<<", "<<htx << CRLF;
 }
 
 
@@ -103,8 +103,8 @@ void CSailCarlsonWriter::write(const CPanelGroup &sail, const QString &filename)
     out << "Sailcut Carlson plotter development: Test1" << CRLF;
 
     unsigned int pn = 0;
-    for (pn = 0; pn < sail.panel.size(); pn++)
-        writePanel( out, sail.panel[pn] );
+    for (pn = 0; pn < sail.size(); pn++)
+        writePanel( out, sail[pn] );
 
     out << "EOF" << CRLF;
     out.close();
@@ -136,57 +136,57 @@ void CSailCarlsonWriter::writePanel(ofstream &out, const CPanel &panel) const
     writePanelHeader(out, panel);
 
     ////  header for draw line
-    writeDraw (out, left.nbpoints()+top.nbpoints()+right.nbpoints()+btm.nbpoints());
+    writeDraw (out, left.size()+top.size()+right.size()+btm.size());
 
     // left edge
-    for (i = 0; i < left.nbpoints(); i++)
+    for (i = 0; i < left.size(); i++)
     {
-        writePoint( out, left.point[i] );
+        writePoint( out, left[i] );
     }
 
     // panel top edge
-    for (i = 0; i < top.nbpoints(); i++)
+    for (i = 0; i < top.size(); i++)
     {
-        writePoint( out, top.point[i] );
+        writePoint( out, top[i] );
     }
 
     // panel right edge
-    for (j = right.nbpoints() -1; j> -1; j--)
+    for (j = right.size() -1; j> -1; j--)
     {
-        writePoint( out, right.point[j] );
+        writePoint( out, right[j] );
     }
 
     //// panel bottom edge
-    for (j = btm.nbpoints() -1; j > -1; j--)
+    for (j = btm.size() -1; j > -1; j--)
     {
-        writePoint( out, btm.point[j] );
+        writePoint( out, btm[j] );
     }
 
     ////  header for cut line
-    writeCut ( out, left.nbpoints()+top.nbpoints()+right.nbpoints()+btm.nbpoints() );
+    writeCut ( out, left.size()+top.size()+right.size()+btm.size() );
 
     // left edge
-    for (i = 0; i < left.nbpoints(); i++)
+    for (i = 0; i < left.size(); i++)
     {
-        writePoint( out, cleft.point[i] );
+        writePoint( out, cleft[i] );
     }
 
     // panel top edge
-    for (i = 0; i < top.nbpoints(); i++)
+    for (i = 0; i < top.size(); i++)
     {
-        writePoint( out, ctop.point[i] );
+        writePoint( out, ctop[i] );
     }
 
     // panel right edge
-    for (j = right.nbpoints() -1; j > - 1; j--)
+    for (j = right.size() -1; j > - 1; j--)
     {
-        writePoint( out, cright.point[j] );
+        writePoint( out, cright[j] );
     }
 
     // panel bottom edge
-    for (j = btm.nbpoints() -1; j > -1; j--)
+    for (j = btm.size() -1; j > -1; j--)
     {
-        writePoint( out, cbtm.point[j] );
+        writePoint( out, cbtm[j] );
     }
 }
 
