@@ -1,36 +1,41 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="1.1" language="en_GB">
 <context>
     <name>CBoatElementWidget</name>
     <message>
         <location filename="../boatdef-panel.cpp" line="137"/>
         <source>Sail information</source>
-        <translation type="unfinished">Sejl information</translation>
+        <translation type="obsolete">Sejl information</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="138"/>
+        <location filename="../boatdef-panel.cpp" line="145"/>
         <source>file</source>
-        <translation type="unfinished">fil</translation>
+        <translation>fil</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="139"/>
+        <location filename="../boatdef-panel.cpp" line="146"/>
         <source>name</source>
-        <translation type="unfinished">navn</translation>
+        <translation>navn</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="140"/>
+        <location filename="../boatdef-panel.cpp" line="147"/>
         <source>Reload</source>
-        <translation type="unfinished">Genindlæs</translation>
+        <translation>Genindlæs</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="141"/>
+        <location filename="../boatdef-panel.cpp" line="148"/>
         <source>Remove</source>
-        <translation type="unfinished">Fjern</translation>
+        <translation>Fjern</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="142"/>
+        <location filename="../boatdef-panel.cpp" line="149"/>
         <source>Update</source>
-        <translation type="unfinished">Opdater</translation>
+        <translation>Opdater</translation>
+    </message>
+    <message>
+        <location filename="../boatdef-panel.cpp" line="144"/>
+        <source>Element information</source>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -61,40 +66,40 @@
     <message>
         <location filename="../filewriter.h" line="66"/>
         <source>Open</source>
-        <translation type="unfinished">Åben</translation>
+        <translation>Åben</translation>
     </message>
     <message>
         <location filename="../filewriter.h" line="88"/>
         <source>There was an error reading from the selected file.</source>
-        <translation type="unfinished">Det var ikke muligt at læse den ønskede fil.</translation>
+        <translation>Det var ikke muligt at læse den ønskede fil.</translation>
     </message>
     <message>
         <location filename="../filewriter.h" line="105"/>
         <source>Save</source>
-        <translation type="unfinished">Gem</translation>
+        <translation>Gem</translation>
     </message>
 </context>
 <context>
     <name>CFormBoat</name>
     <message>
-        <location filename="../formboat.cpp" line="97"/>
+        <location filename="../formboat.cpp" line="104"/>
         <source>boat</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formboat.cpp" line="98"/>
+        <location filename="../formboat.cpp" line="105"/>
         <source>&amp;Add</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formboat.cpp" line="99"/>
+        <location filename="../formboat.cpp" line="106"/>
         <source>file</source>
-        <translation type="unfinished">fil</translation>
+        <translation>fil</translation>
     </message>
     <message>
-        <location filename="../formboat.cpp" line="160"/>
+        <location filename="../formboat.cpp" line="167"/>
         <source>Open</source>
-        <translation type="unfinished">Åben</translation>
+        <translation>Åben</translation>
     </message>
 </context>
 <context>
@@ -115,7 +120,7 @@
     <message>
         <location filename="../formhull.cpp" line="58"/>
         <source>&amp;Dimensions</source>
-        <translation type="unfinished">&amp;Dimensionering</translation>
+        <translation>&amp;Dimensionering</translation>
     </message>
 </context>
 <context>
@@ -168,7 +173,7 @@
     <message>
         <location filename="../formhulldefbase.ui" line="290"/>
         <source>%</source>
-        <translation type="unfinished">%</translation>
+        <translation>%</translation>
     </message>
     <message>
         <location filename="../formhulldefbase.ui" line="402"/>
@@ -288,12 +293,12 @@
     <message>
         <location filename="../formhulldefbase.ui" line="1781"/>
         <source>OK</source>
-        <translation type="unfinished">OK</translation>
+        <translation>OK</translation>
     </message>
     <message>
         <location filename="../formhulldefbase.ui" line="1788"/>
         <source>Cancel</source>
-        <translation type="unfinished">Annuller</translation>
+        <translation>Annuller</translation>
     </message>
     <message>
         <location filename="../formhulldefbase.ui" line="1817"/>
@@ -359,17 +364,17 @@
 <context>
     <name>CFormMain</name>
     <message>
-        <location filename="../formmain.cpp" line="129"/>
+        <location filename="../formmain.cpp" line="131"/>
         <source>&amp;New</source>
         <translation>&amp;Ny</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="134"/>
+        <location filename="../formmain.cpp" line="136"/>
         <source>&amp;Open</source>
         <translation>&amp;Åben</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="135"/>
+        <location filename="../formmain.cpp" line="137"/>
         <source>Open &amp;recent</source>
         <translation>Åben &amp;seneste</translation>
     </message>
@@ -394,12 +399,12 @@
         <translation type="obsolete">&amp;Udskriv</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="136"/>
+        <location filename="../formmain.cpp" line="138"/>
         <source>&amp;Save</source>
         <translation>&amp;Gem</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="137"/>
+        <location filename="../formmain.cpp" line="139"/>
         <source>Save &amp;As</source>
         <translation>Gem &amp;Som</translation>
     </message>
@@ -434,7 +439,7 @@
         <translation type="obsolete">Eksporter &amp;design sæt</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="139"/>
+        <location filename="../formmain.cpp" line="141"/>
         <source>&amp;Quit</source>
         <translation>&amp;Afslut</translation>
     </message>
@@ -459,37 +464,37 @@
         <translation type="obsolete">&amp;Rig</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="143"/>
+        <location filename="../formmain.cpp" line="145"/>
         <source>Language</source>
         <translation>Sprog</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="154"/>
+        <location filename="../formmain.cpp" line="156"/>
         <source>Sailcut CAD &amp;Handbook</source>
         <translation>Sailcut CAD &amp;Håndbog</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="155"/>
+        <location filename="../formmain.cpp" line="157"/>
         <source>About &amp;Qt</source>
         <translation>Om &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="156"/>
+        <location filename="../formmain.cpp" line="158"/>
         <source>About &amp;Sailcut CAD</source>
         <translation>Om &amp;Sailcut CAD</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="127"/>
+        <location filename="../formmain.cpp" line="129"/>
         <source>&amp;File</source>
         <translation>&amp;Fil</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="142"/>
+        <location filename="../formmain.cpp" line="144"/>
         <source>&amp;View</source>
         <translation>&amp;Vælg</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="153"/>
+        <location filename="../formmain.cpp" line="155"/>
         <source>&amp;Help</source>
         <translation>&amp;Hjælp</translation>
     </message>
@@ -509,7 +514,7 @@
         <translation type="obsolete">Design sæt</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="203"/>
+        <location filename="../formmain.cpp" line="215"/>
         <source>loaded &apos;%1&apos;</source>
         <translation>Åbnet &apos;%1&apos;</translation>
     </message>
@@ -519,12 +524,12 @@
         <translation type="obsolete">udviklet nyt sejl</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="317"/>
+        <location filename="../formmain.cpp" line="334"/>
         <source>About Sailcut CAD</source>
         <translation>Om Sailcut CAD</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="206"/>
+        <location filename="../formmain.cpp" line="220"/>
         <source>error loading &apos;%1&apos;</source>
         <translation>Fejl i åbning &apos;%1&apos;</translation>
     </message>
@@ -799,7 +804,7 @@
         <translation type="obsolete">Der var fejl ved udskrivning af tegning</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="478"/>
+        <location filename="../formmain.cpp" line="504"/>
         <source>wrote &apos;%1&apos;</source>
         <translation>skrevet &apos;%1&apos;</translation>
     </message>
@@ -829,59 +834,59 @@
         <translation type="obsolete">&amp;Håndplotting format</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="130"/>
+        <location filename="../formmain.cpp" line="132"/>
         <source>sail</source>
-        <translation type="unfinished"></translation>
+        <translation>Sejl</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="131"/>
+        <location filename="../formmain.cpp" line="133"/>
         <source>hull</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="132"/>
+        <location filename="../formmain.cpp" line="134"/>
         <source>rig</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="133"/>
+        <location filename="../formmain.cpp" line="135"/>
         <source>boat</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="146"/>
+        <location filename="../formmain.cpp" line="148"/>
         <source>&amp;Window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="147"/>
+        <location filename="../formmain.cpp" line="149"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Luk</translation>
+        <translation>&amp;Luk</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="148"/>
+        <location filename="../formmain.cpp" line="150"/>
         <source>Close &amp;All</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="149"/>
+        <location filename="../formmain.cpp" line="151"/>
         <source>&amp;Tile</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="150"/>
+        <location filename="../formmain.cpp" line="152"/>
         <source>&amp;Cascade</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="195"/>
+        <location filename="../formmain.cpp" line="207"/>
         <source>unknown document type &apos;%1&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="435"/>
+        <location filename="../formmain.cpp" line="461"/>
         <source>Open</source>
-        <translation type="unfinished">Åben</translation>
+        <translation>Åben</translation>
     </message>
 </context>
 <context>
@@ -1005,12 +1010,12 @@
     <message>
         <location filename="../formrig.cpp" line="59"/>
         <source>rig</source>
-        <translation type="unfinished"></translation>
+        <translation>Rig</translation>
     </message>
     <message>
         <location filename="../formrig.cpp" line="60"/>
         <source>&amp;Dimensions</source>
-        <translation type="unfinished">&amp;Dimensionering</translation>
+        <translation>&amp;Dimensionering</translation>
     </message>
 </context>
 <context>
@@ -1018,17 +1023,17 @@
     <message>
         <location filename="../formrigdefbase.ui" line="20"/>
         <source>Rig dimensions</source>
-        <translation type="unfinished"></translation>
+        <translation>Rig dimensioner</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="53"/>
         <source>Cancel</source>
-        <translation type="unfinished">Annuller</translation>
+        <translation>Annuller</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="68"/>
         <source>OK</source>
-        <translation type="unfinished">OK</translation>
+        <translation>OK</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="75"/>
@@ -1368,7 +1373,7 @@
     <message>
         <location filename="../formrigdefbase.ui" line="1309"/>
         <source>Luff round</source>
-        <translation type="unfinished">Forli runding</translation>
+        <translation>Forli runding</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="1333"/>
@@ -1438,126 +1443,131 @@
 </context>
 <context>
     <name>CFormSail</name>
-    <message>
-        <location filename="../formsail.cpp" line="69"/>
-        <source>sail</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="72"/>
-        <source>&amp;Print</source>
-        <translation type="unfinished">&amp;Udskriv</translation>
-    </message>
     <message>
         <location filename="../formsail.cpp" line="73"/>
+        <source>sail</source>
+        <translation>Sejl</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="76"/>
+        <source>&amp;Print</source>
+        <translation>&amp;Udskriv</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="77"/>
         <source>data</source>
-        <translation type="unfinished">data</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="74"/>
-        <source>drawing</source>
-        <translation type="unfinished">tegning</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="99"/>
-        <source>development</source>
-        <translation type="unfinished">Design sæt</translation>
+        <translation>data</translation>
     </message>
     <message>
         <location filename="../formsail.cpp" line="78"/>
+        <source>drawing</source>
+        <translation>tegning</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="106"/>
+        <source>development</source>
+        <translation>Design sæt</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="82"/>
         <source>E&amp;xport 3D sail</source>
-        <translation type="unfinished">E&amp;ksporter 3D sejl</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="86"/>
-        <source>to &amp;DXF</source>
-        <translation type="unfinished">til &amp;DXF format</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="89"/>
-        <source>to &amp;TXT sail</source>
-        <translation type="unfinished">til &amp;TXT format</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="90"/>
-        <source>to &amp;XML sail</source>
-        <translation type="unfinished">til &amp;XML format</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="84"/>
-        <source>Export &amp;development</source>
-        <translation type="unfinished">Eksporter &amp;design sæt</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="85"/>
-        <source>to &amp;Carlson plotter</source>
-        <translation type="unfinished">til C&amp;arlson plotter</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="88"/>
-        <source>to &amp;Hand-plotting format</source>
-        <translation type="unfinished">&amp;Håndplotting format</translation>
+        <translation>E&amp;ksporter 3D sejl</translation>
     </message>
     <message>
         <location filename="../formsail.cpp" line="93"/>
-        <source>&amp;Dimensions</source>
-        <translation type="unfinished">&amp;Dimensionering</translation>
+        <source>to &amp;DXF</source>
+        <translation>til &amp;DXF format</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="94"/>
-        <source>&amp;Mould</source>
-        <translation type="unfinished">&amp;Form</translation>
+        <location filename="../formsail.cpp" line="96"/>
+        <source>to &amp;TXT sail</source>
+        <translation>til &amp;TXT format</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="97"/>
+        <source>to &amp;XML sail</source>
+        <translation>til &amp;XML format</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="91"/>
+        <source>Export &amp;development</source>
+        <translation>Eksporter &amp;design sæt</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="92"/>
+        <source>to &amp;Carlson plotter</source>
+        <translation>til C&amp;arlson plotter</translation>
     </message>
     <message>
         <location filename="../formsail.cpp" line="95"/>
+        <source>to &amp;Hand-plotting format</source>
+        <translation>&amp;Håndplotting format</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="100"/>
+        <source>&amp;Dimensions</source>
+        <translation>&amp;Dimensionering</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="101"/>
+        <source>&amp;Mould</source>
+        <translation>&amp;Form</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="102"/>
         <source>&amp;Patches</source>
-        <translation type="unfinished">&amp;Hjørnelapper</translation>
+        <translation>&amp;Hjørnelapper</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="365"/>
+        <location filename="../formsail.cpp" line="393"/>
         <source>error</source>
-        <translation type="unfinished"></translation>
+        <translation>Fejl</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="312"/>
+        <location filename="../formsail.cpp" line="336"/>
         <source>There was a data printing error</source>
-        <translation type="unfinished">Der var fejl ved udskrivning af data</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="339"/>
-        <source>There was a development printing error</source>
-        <translation type="unfinished">Der var fejl ved udskrivning af design sæt</translation>
+        <translation>Der var fejl ved udskrivning af data</translation>
     </message>
     <message>
         <location filename="../formsail.cpp" line="365"/>
+        <source>There was a development printing error</source>
+        <translation>Der var fejl ved udskrivning af design sæt</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="393"/>
         <source>There was a drawing printing error</source>
-        <translation type="unfinished">Der var fejl ved udskrivning af tegning</translation>
+        <translation>Der var fejl ved udskrivning af tegning</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="85"/>
+        <source>to &amp;SVG</source>
+        <translation>&amp;SVG</translation>
     </message>
 </context>
 <context>
     <name>CFormSailDef</name>
     <message>
-        <location filename="../formsaildef.cpp" line="1087"/>
+        <location filename="../formsaildef.cpp" line="1090"/>
         <source>Sail corners coordinates</source>
         <translation>Sejllhjørne koordinator</translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1088"/>
+        <location filename="../formsaildef.cpp" line="1091"/>
         <source>tack</source>
         <translation>halsbarm</translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1089"/>
+        <location filename="../formsaildef.cpp" line="1092"/>
         <source>clew</source>
         <translation>klampe</translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1090"/>
+        <location filename="../formsaildef.cpp" line="1093"/>
         <source>head</source>
         <translation>hoved</translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1091"/>
+        <location filename="../formsaildef.cpp" line="1094"/>
         <source>peak</source>
         <translation>top</translation>
     </message>
@@ -1567,9 +1577,9 @@
         <translation type="obsolete">IRC med målinger</translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1096"/>
+        <location filename="../formsaildef.cpp" line="1099"/>
         <source>Sail width measurements </source>
-        <translation type="unfinished"></translation>
+        <translation>Sejl med målinger </translation>
     </message>
 </context>
 <context>
@@ -1910,267 +1920,267 @@ stævn</translation>
 <context>
     <name>CSailPrinter</name>
     <message>
-        <location filename="../sailprinter.cpp" line="150"/>
+        <location filename="../sailprinter.cpp" line="152"/>
         <source>Sailcut CAD data sheet</source>
         <translation>Sailcut CAD data side</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="156"/>
+        <location filename="../sailprinter.cpp" line="158"/>
         <source>Mainsail</source>
         <translation>Storsejl</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="159"/>
+        <location filename="../sailprinter.cpp" line="161"/>
         <source>Jib</source>
         <translation>Fok</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="162"/>
+        <location filename="../sailprinter.cpp" line="164"/>
         <source>Wing</source>
         <translation>Vinge</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="162"/>
+        <location filename="../sailprinter.cpp" line="164"/>
         <source>deg</source>
         <translation>grd</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="165"/>
+        <location filename="../sailprinter.cpp" line="167"/>
         <source>Sail type</source>
         <translation>Sejl type</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="171"/>
+        <location filename="../sailprinter.cpp" line="173"/>
         <source>Cross Cut</source>
         <translation>Cross Cut</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="174"/>
+        <location filename="../sailprinter.cpp" line="176"/>
         <source>Horizontal Cut</source>
         <translation>Horisontal Cut</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="177"/>
+        <location filename="../sailprinter.cpp" line="179"/>
         <source>Radial Cut</source>
         <translation>Radial Cut</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="178"/>
+        <location filename="../sailprinter.cpp" line="180"/>
         <source>sections</source>
         <translation>sektioner</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="179"/>
+        <location filename="../sailprinter.cpp" line="181"/>
         <source>head gores</source>
         <translation>hoved kiler</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="180"/>
+        <location filename="../sailprinter.cpp" line="182"/>
         <source>luff gores</source>
         <translation>forli kiler</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="183"/>
+        <location filename="../sailprinter.cpp" line="185"/>
         <source>Twist Foot Cut</source>
         <translation>Twistet Foot Cut</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="186"/>
+        <location filename="../sailprinter.cpp" line="188"/>
         <source>Vertical Cut</source>
         <translation>Vertikal Cut</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="189"/>
+        <location filename="../sailprinter.cpp" line="191"/>
         <source>Mitre Cut</source>
         <translation>Mitre Cut</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="192"/>
+        <location filename="../sailprinter.cpp" line="194"/>
         <source>Sail layout</source>
         <translation>Sejl layout</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="195"/>
+        <location filename="../sailprinter.cpp" line="197"/>
         <source>Rig</source>
         <translation>Rig</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="196"/>
+        <location filename="../sailprinter.cpp" line="198"/>
         <source>Boat LOA</source>
         <translation>Bådens LOA</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="197"/>
+        <location filename="../sailprinter.cpp" line="199"/>
         <source>Mast/Luff rake</source>
         <translation>Maste/Forli hældning</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="198"/>
+        <location filename="../sailprinter.cpp" line="200"/>
         <source>Tack position X</source>
         <translation>Halsbarm position X</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="199"/>
+        <location filename="../sailprinter.cpp" line="201"/>
         <source>Tack height Y</source>
         <translation>Halsbarm højde Y</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="200"/>
+        <location filename="../sailprinter.cpp" line="202"/>
         <source>Fore triangle hoist I</source>
         <translation>Forstags længde I mål</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="201"/>
+        <location filename="../sailprinter.cpp" line="203"/>
         <source>Fore triangle base J</source>
         <translation>Afstand fra forstævn til mast, J mål</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="204"/>
+        <location filename="../sailprinter.cpp" line="206"/>
         <source>Sail dimensions</source>
         <translation>Sejl dimension</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="205"/>
+        <location filename="../sailprinter.cpp" line="207"/>
         <source>Luff length</source>
         <translation>Forli længde</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="206"/>
+        <location filename="../sailprinter.cpp" line="208"/>
         <source>Foot length</source>
         <translation>Sejlfod længde</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="207"/>
+        <location filename="../sailprinter.cpp" line="209"/>
         <source>Leech length</source>
         <translation>Bagli længde</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="208"/>
+        <location filename="../sailprinter.cpp" line="210"/>
         <source>Gaff length</source>
         <translation>Gaffel længde</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="209"/>
+        <location filename="../sailprinter.cpp" line="211"/>
         <source>Gaff angle wrt luff</source>
         <translation>Gaffel vinkel fra forli</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="212"/>
+        <location filename="../sailprinter.cpp" line="214"/>
         <source>Shape of edges</source>
         <translation>Kanternes form</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="213"/>
+        <location filename="../sailprinter.cpp" line="215"/>
         <source>Luff round</source>
         <translation>Forli runding</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="214"/>
+        <location filename="../sailprinter.cpp" line="216"/>
         <source>Luff round position</source>
         <translation>Forli rundings position</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="215"/>
+        <location filename="../sailprinter.cpp" line="217"/>
         <source>Foot round</source>
         <translation>Fodrunding</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="216"/>
+        <location filename="../sailprinter.cpp" line="218"/>
         <source>Foot round position</source>
         <translation>Sejlfods rundings position</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="217"/>
+        <location filename="../sailprinter.cpp" line="219"/>
         <source>Leech round</source>
         <translation>Bagli runding</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="218"/>
+        <location filename="../sailprinter.cpp" line="220"/>
         <source>Leech round position</source>
         <translation>Bagli rundings position</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="219"/>
+        <location filename="../sailprinter.cpp" line="221"/>
         <source>Gaff round</source>
         <translation>Gaffel runding</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="220"/>
+        <location filename="../sailprinter.cpp" line="222"/>
         <source>Gaff round position</source>
         <translation>Position af Gaffel runding</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="223"/>
+        <location filename="../sailprinter.cpp" line="225"/>
         <source>Sail settings</source>
         <translation>Sejl egenskaber</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="224"/>
+        <location filename="../sailprinter.cpp" line="226"/>
         <source>Twist angle</source>
         <translation>Tvist vinkel</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="225"/>
+        <location filename="../sailprinter.cpp" line="227"/>
         <source>Sheeting angle</source>
         <translation>Lag vinkel</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="228"/>
+        <location filename="../sailprinter.cpp" line="230"/>
         <source>Cloth seams and hems</source>
         <translation>Sømme og kantninger</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="229"/>
+        <location filename="../sailprinter.cpp" line="231"/>
         <source>Cloth width</source>
         <translation>Tekstil bredde</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="230"/>
+        <location filename="../sailprinter.cpp" line="232"/>
         <source>Seams width</source>
         <translation>Sømbredde</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="231"/>
+        <location filename="../sailprinter.cpp" line="233"/>
         <source>Leech hem width</source>
         <translation>Bredde på bagli søm</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="232"/>
+        <location filename="../sailprinter.cpp" line="234"/>
         <source>Other hem width</source>
         <translation>Andre søm bredde</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="235"/>
+        <location filename="../sailprinter.cpp" line="237"/>
         <source>Sail mould</source>
         <translation>Sejl form</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="236"/>
+        <location filename="../sailprinter.cpp" line="238"/>
         <source>Luff factor</source>
         <translation>Forli faktor</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="236"/>
+        <location filename="../sailprinter.cpp" line="238"/>
         <source>Depth</source>
         <translation>Dybde</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="236"/>
+        <location filename="../sailprinter.cpp" line="238"/>
         <source>Leech factor</source>
         <translation>Bagli faktor</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="238"/>
+        <location filename="../sailprinter.cpp" line="240"/>
         <source>Top profile</source>
         <translation>Øverste profil</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="244"/>
+        <location filename="../sailprinter.cpp" line="246"/>
         <source>Mid profile at h = </source>
         <translation>Midter profil ved h =</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="250"/>
+        <location filename="../sailprinter.cpp" line="252"/>
         <source>Bottom profile</source>
         <translation>Nederste profil</translation>
     </message>
@@ -2228,43 +2238,43 @@ stævn</translation>
     <message>
         <location filename="../sailviewer-tabs.cpp" line="64"/>
         <source>shaded view</source>
-        <translation type="unfinished">3D visning</translation>
+        <translation>3D visning</translation>
     </message>
     <message>
         <location filename="../sailviewer-tabs.cpp" line="66"/>
         <source>wireframe view</source>
-        <translation type="unfinished">Trådramme visning</translation>
+        <translation>Trådramme visning</translation>
     </message>
 </context>
 <context>
     <name>CWidgetProfile</name>
     <message>
-        <location filename="../widgetprofile.cpp" line="242"/>
+        <location filename="../widgetprofile.cpp" line="240"/>
         <source>Luff shape</source>
         <translation>Forli form</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="243"/>
+        <location filename="../widgetprofile.cpp" line="241"/>
         <source>Depth</source>
         <translation>Dybde</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="244"/>
+        <location filename="../widgetprofile.cpp" line="242"/>
         <source>%</source>
         <translation>%</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="245"/>
+        <location filename="../widgetprofile.cpp" line="243"/>
         <source>Leech shape</source>
         <translation>Bagli form</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="249"/>
+        <location filename="../widgetprofile.cpp" line="247"/>
         <source>degrees</source>
         <translation>grader</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="248"/>
+        <location filename="../widgetprofile.cpp" line="246"/>
         <source>cord</source>
         <translation type="unfinished"></translation>
     </message>
