@@ -5,33 +5,38 @@
     <message>
         <location filename="../boatdef-panel.cpp" line="137"/>
         <source>Sail information</source>
-        <translation>Informazioni vela</translation>
+        <translation type="obsolete">Informazioni vela</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="138"/>
+        <location filename="../boatdef-panel.cpp" line="145"/>
         <source>file</source>
         <translation>file</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="139"/>
+        <location filename="../boatdef-panel.cpp" line="146"/>
         <source>name</source>
         <translation>nome</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="140"/>
+        <location filename="../boatdef-panel.cpp" line="147"/>
         <source>Reload</source>
         <translation>Ricarica</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="141"/>
+        <location filename="../boatdef-panel.cpp" line="148"/>
         <source>Remove</source>
         <translation>Cancella</translation>
     </message>
     <message>
-        <location filename="../boatdef-panel.cpp" line="142"/>
+        <location filename="../boatdef-panel.cpp" line="149"/>
         <source>Update</source>
         <translation>Aggiorna</translation>
     </message>
+    <message>
+        <location filename="../boatdef-panel.cpp" line="144"/>
+        <source>Element information</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CFileIO</name>
@@ -77,22 +82,22 @@
 <context>
     <name>CFormBoat</name>
     <message>
-        <location filename="../formboat.cpp" line="97"/>
+        <location filename="../formboat.cpp" line="104"/>
         <source>boat</source>
         <translation>barca</translation>
     </message>
     <message>
-        <location filename="../formboat.cpp" line="98"/>
+        <location filename="../formboat.cpp" line="105"/>
         <source>&amp;Add</source>
         <translation>&amp;Aggiungi</translation>
     </message>
     <message>
-        <location filename="../formboat.cpp" line="99"/>
+        <location filename="../formboat.cpp" line="106"/>
         <source>file</source>
         <translation>file</translation>
     </message>
     <message>
-        <location filename="../formboat.cpp" line="160"/>
+        <location filename="../formboat.cpp" line="167"/>
         <source>Open</source>
         <translation>Aprire</translation>
     </message>
@@ -110,7 +115,7 @@
     <message>
         <location filename="../formhull.cpp" line="57"/>
         <source>hull</source>
-        <translation type="unfinished"></translation>
+        <translation>buccia</translation>
     </message>
     <message>
         <location filename="../formhull.cpp" line="58"/>
@@ -168,7 +173,7 @@
     <message>
         <location filename="../formhulldefbase.ui" line="290"/>
         <source>%</source>
-        <translation type="unfinished">%</translation>
+        <translation>%</translation>
     </message>
     <message>
         <location filename="../formhulldefbase.ui" line="402"/>
@@ -288,12 +293,12 @@
     <message>
         <location filename="../formhulldefbase.ui" line="1781"/>
         <source>OK</source>
-        <translation type="unfinished">OK</translation>
+        <translation>OK</translation>
     </message>
     <message>
         <location filename="../formhulldefbase.ui" line="1788"/>
         <source>Cancel</source>
-        <translation type="unfinished">Cancellare</translation>
+        <translation>Cancellare</translation>
     </message>
     <message>
         <location filename="../formhulldefbase.ui" line="1817"/>
@@ -374,27 +379,27 @@
         <translation type="obsolete">vela &amp;XML</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="129"/>
+        <location filename="../formmain.cpp" line="131"/>
         <source>&amp;New</source>
         <translation>&amp;Nuovo</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="134"/>
+        <location filename="../formmain.cpp" line="136"/>
         <source>&amp;Open</source>
         <translation>&amp;Aprire</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="136"/>
+        <location filename="../formmain.cpp" line="138"/>
         <source>&amp;Save</source>
         <translation>&amp;Salvare</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="137"/>
+        <location filename="../formmain.cpp" line="139"/>
         <source>Save &amp;As</source>
         <translation>Salvare &amp;sotto</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="139"/>
+        <location filename="../formmain.cpp" line="141"/>
         <source>&amp;Quit</source>
         <translation>&amp;Uscire</translation>
     </message>
@@ -419,22 +424,22 @@
         <translation type="obsolete">&amp;Attrezzatura</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="127"/>
+        <location filename="../formmain.cpp" line="129"/>
         <source>&amp;File</source>
         <translation>&amp;File</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="142"/>
+        <location filename="../formmain.cpp" line="144"/>
         <source>&amp;View</source>
         <translation>&amp;Vista</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="153"/>
+        <location filename="../formmain.cpp" line="155"/>
         <source>&amp;Help</source>
         <translation>&amp;Aiuto</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="317"/>
+        <location filename="../formmain.cpp" line="334"/>
         <source>About Sailcut CAD</source>
         <translation>A proposito di Sailcut CAD</translation>
     </message>
@@ -449,22 +454,22 @@
         <translation type="obsolete">Errore di scrittura sul file selezionato</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="155"/>
+        <location filename="../formmain.cpp" line="157"/>
         <source>About &amp;Qt</source>
         <translation>A proposito di &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="156"/>
+        <location filename="../formmain.cpp" line="158"/>
         <source>About &amp;Sailcut CAD</source>
         <translation>A proposito di &amp;Sailcut CAD</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="143"/>
+        <location filename="../formmain.cpp" line="145"/>
         <source>Language</source>
         <translation>Lingua</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="135"/>
+        <location filename="../formmain.cpp" line="137"/>
         <source>Open &amp;recent</source>
         <translation>Apri &amp;recente</translation>
     </message>
@@ -484,7 +489,7 @@
         <translation type="obsolete">Esporta &amp;svilupppo</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="154"/>
+        <location filename="../formmain.cpp" line="156"/>
         <source>Sailcut CAD &amp;Handbook</source>
         <translation>Manuale &amp;Sailcut CAD</translation>
     </message>
@@ -509,17 +514,17 @@
         <translation type="obsolete">nuova vela creata</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="203"/>
+        <location filename="../formmain.cpp" line="215"/>
         <source>loaded &apos;%1&apos;</source>
         <translation>caricata &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="206"/>
+        <location filename="../formmain.cpp" line="220"/>
         <source>error loading &apos;%1&apos;</source>
         <translation>errore caricamento &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="478"/>
+        <location filename="../formmain.cpp" line="504"/>
         <source>wrote &apos;%1&apos;</source>
         <translation>ha scritto &apos;%1&apos;</translation>
     </message>
@@ -818,60 +823,60 @@
         <source>deg</source>
         <translation type="obsolete">deg</translation>
     </message>
-    <message>
-        <location filename="../formmain.cpp" line="130"/>
-        <source>sail</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../formmain.cpp" line="131"/>
-        <source>hull</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../formmain.cpp" line="132"/>
-        <source>rig</source>
-        <translation type="unfinished"></translation>
+        <source>sail</source>
+        <translation>vela</translation>
     </message>
     <message>
         <location filename="../formmain.cpp" line="133"/>
-        <source>boat</source>
-        <translation type="unfinished">barca</translation>
+        <source>hull</source>
+        <translation>buccia</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="146"/>
+        <location filename="../formmain.cpp" line="134"/>
+        <source>rig</source>
+        <translation>attrezzatura</translation>
+    </message>
+    <message>
+        <location filename="../formmain.cpp" line="135"/>
+        <source>boat</source>
+        <translation>barca</translation>
+    </message>
+    <message>
+        <location filename="../formmain.cpp" line="148"/>
         <source>&amp;Window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="147"/>
+        <location filename="../formmain.cpp" line="149"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Chiudere</translation>
+        <translation>&amp;Chiudere</translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="148"/>
+        <location filename="../formmain.cpp" line="150"/>
         <source>Close &amp;All</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="149"/>
+        <location filename="../formmain.cpp" line="151"/>
         <source>&amp;Tile</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="150"/>
+        <location filename="../formmain.cpp" line="152"/>
         <source>&amp;Cascade</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="195"/>
+        <location filename="../formmain.cpp" line="207"/>
         <source>unknown document type &apos;%1&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formmain.cpp" line="435"/>
+        <location filename="../formmain.cpp" line="461"/>
         <source>Open</source>
-        <translation type="unfinished">Aprire</translation>
+        <translation>Aprire</translation>
     </message>
 </context>
 <context>
@@ -1000,7 +1005,7 @@
     <message>
         <location filename="../formrig.cpp" line="60"/>
         <source>&amp;Dimensions</source>
-        <translation type="unfinished">&amp;Dimensioni</translation>
+        <translation>&amp;Dimensioni</translation>
     </message>
 </context>
 <context>
@@ -1008,17 +1013,17 @@
     <message>
         <location filename="../formrigdefbase.ui" line="20"/>
         <source>Rig dimensions</source>
-        <translation type="unfinished"></translation>
+        <translation>Dimensioni attrezzatura</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="53"/>
         <source>Cancel</source>
-        <translation type="unfinished">Cancellare</translation>
+        <translation>Cancellare</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="68"/>
         <source>OK</source>
-        <translation type="unfinished">OK</translation>
+        <translation>OK</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="75"/>
@@ -1298,7 +1303,7 @@
     <message>
         <location filename="../formrigdefbase.ui" line="1015"/>
         <source>Mainsail</source>
-        <translation type="unfinished">Randa</translation>
+        <translation>Randa</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="1044"/>
@@ -1353,12 +1358,12 @@
     <message>
         <location filename="../formrigdefbase.ui" line="1288"/>
         <source>Luff length </source>
-        <translation type="unfinished"></translation>
+        <translation>Lunghezza del ghindante</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="1309"/>
         <source>Luff round</source>
-        <translation type="unfinished">Allunamento del ghindante</translation>
+        <translation>Allunamento del ghindante</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="1333"/>
@@ -1428,126 +1433,131 @@
 </context>
 <context>
     <name>CFormSail</name>
-    <message>
-        <location filename="../formsail.cpp" line="69"/>
-        <source>sail</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="72"/>
-        <source>&amp;Print</source>
-        <translation type="unfinished">&amp;Stampa</translation>
-    </message>
     <message>
         <location filename="../formsail.cpp" line="73"/>
+        <source>sail</source>
+        <translation>vela</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="76"/>
+        <source>&amp;Print</source>
+        <translation>&amp;Stampa</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="77"/>
         <source>data</source>
-        <translation type="unfinished">dati</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="74"/>
-        <source>drawing</source>
-        <translation type="unfinished">disegno</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="99"/>
-        <source>development</source>
-        <translation type="unfinished">sviluppo</translation>
+        <translation>dati</translation>
     </message>
     <message>
         <location filename="../formsail.cpp" line="78"/>
+        <source>drawing</source>
+        <translation>disegno</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="106"/>
+        <source>development</source>
+        <translation>sviluppo</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="82"/>
         <source>E&amp;xport 3D sail</source>
-        <translation type="unfinished">Esporta &amp;vela 3D</translation>
+        <translation>Esporta &amp;vela 3D</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="86"/>
+        <location filename="../formsail.cpp" line="93"/>
         <source>to &amp;DXF</source>
-        <translation type="unfinished">&amp;DXF</translation>
+        <translation>&amp;DXF</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="89"/>
+        <location filename="../formsail.cpp" line="96"/>
         <source>to &amp;TXT sail</source>
-        <translation type="unfinished">vela &amp;TXT</translation>
+        <translation>vela &amp;TXT</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="90"/>
+        <location filename="../formsail.cpp" line="97"/>
         <source>to &amp;XML sail</source>
-        <translation type="unfinished">vela &amp;XML</translation>
+        <translation>vela &amp;XML</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="84"/>
+        <location filename="../formsail.cpp" line="91"/>
         <source>Export &amp;development</source>
-        <translation type="unfinished">Esporta &amp;svilupppo</translation>
+        <translation>Esporta &amp;svilupppo</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="85"/>
+        <location filename="../formsail.cpp" line="92"/>
         <source>to &amp;Carlson plotter</source>
-        <translation type="unfinished">al plotter &amp;Carlson</translation>
+        <translation>al plotter &amp;Carlson</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="88"/>
+        <location filename="../formsail.cpp" line="95"/>
         <source>to &amp;Hand-plotting format</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="93"/>
+        <location filename="../formsail.cpp" line="100"/>
         <source>&amp;Dimensions</source>
-        <translation type="unfinished">&amp;Dimensioni</translation>
+        <translation>&amp;Dimensioni</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="94"/>
+        <location filename="../formsail.cpp" line="101"/>
         <source>&amp;Mould</source>
-        <translation type="unfinished">&amp;Profilo</translation>
+        <translation>&amp;Profilo</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="95"/>
+        <location filename="../formsail.cpp" line="102"/>
         <source>&amp;Patches</source>
-        <translation type="unfinished">&amp;Rinforzi</translation>
+        <translation>&amp;Rinforzi</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="365"/>
+        <location filename="../formsail.cpp" line="393"/>
         <source>error</source>
-        <translation type="unfinished">errore</translation>
+        <translation>errore</translation>
     </message>
     <message>
-        <location filename="../formsail.cpp" line="312"/>
+        <location filename="../formsail.cpp" line="336"/>
         <source>There was a data printing error</source>
-        <translation type="unfinished">Errore di stampa dati</translation>
-    </message>
-    <message>
-        <location filename="../formsail.cpp" line="339"/>
-        <source>There was a development printing error</source>
-        <translation type="unfinished">Errore di stampa sviluppo</translation>
+        <translation>Errore di stampa dati</translation>
     </message>
     <message>
         <location filename="../formsail.cpp" line="365"/>
+        <source>There was a development printing error</source>
+        <translation>Errore di stampa sviluppo</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="393"/>
         <source>There was a drawing printing error</source>
-        <translation type="unfinished">Errore di stampa disegno</translation>
+        <translation>Errore di stampa disegno</translation>
+    </message>
+    <message>
+        <location filename="../formsail.cpp" line="85"/>
+        <source>to &amp;SVG</source>
+        <translation>&amp;SVG</translation>
     </message>
 </context>
 <context>
     <name>CFormSailDef</name>
     <message>
-        <location filename="../formsaildef.cpp" line="1087"/>
+        <location filename="../formsaildef.cpp" line="1090"/>
         <source>Sail corners coordinates</source>
         <translation>Vela circonda coordinate</translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1088"/>
+        <location filename="../formsaildef.cpp" line="1091"/>
         <source>tack</source>
         <translation>chiodino</translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1089"/>
+        <location filename="../formsaildef.cpp" line="1092"/>
         <source>clew</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1090"/>
+        <location filename="../formsaildef.cpp" line="1093"/>
         <source>head</source>
         <translation>testa</translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1091"/>
+        <location filename="../formsaildef.cpp" line="1094"/>
         <source>peak</source>
         <translation>vetta</translation>
     </message>
@@ -1557,7 +1567,7 @@
         <translation type="obsolete">IRC misure di ampiezza</translation>
     </message>
     <message>
-        <location filename="../formsaildef.cpp" line="1096"/>
+        <location filename="../formsaildef.cpp" line="1099"/>
         <source>Sail width measurements </source>
         <translation type="unfinished"></translation>
     </message>
@@ -1904,267 +1914,267 @@
 <context>
     <name>CSailPrinter</name>
     <message>
-        <location filename="../sailprinter.cpp" line="150"/>
+        <location filename="../sailprinter.cpp" line="152"/>
         <source>Sailcut CAD data sheet</source>
         <translation>Scheda dati Sailcut CAD</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="156"/>
+        <location filename="../sailprinter.cpp" line="158"/>
         <source>Mainsail</source>
         <translation>Randa</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="159"/>
+        <location filename="../sailprinter.cpp" line="161"/>
         <source>Jib</source>
         <translation>Fiocco</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="162"/>
+        <location filename="../sailprinter.cpp" line="164"/>
         <source>Wing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="162"/>
+        <location filename="../sailprinter.cpp" line="164"/>
         <source>deg</source>
         <translation>deg</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="165"/>
+        <location filename="../sailprinter.cpp" line="167"/>
         <source>Sail type</source>
         <translation>Tipo vela</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="171"/>
+        <location filename="../sailprinter.cpp" line="173"/>
         <source>Cross Cut</source>
         <translation>Taglio cross-cut</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="174"/>
+        <location filename="../sailprinter.cpp" line="176"/>
         <source>Horizontal Cut</source>
         <translation>Taglio orizzontale</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="177"/>
+        <location filename="../sailprinter.cpp" line="179"/>
         <source>Radial Cut</source>
         <translation>Taglio radiale</translation>
     </message>
-    <message>
-        <location filename="../sailprinter.cpp" line="178"/>
-        <source>sections</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../sailprinter.cpp" line="179"/>
-        <source>head gores</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../sailprinter.cpp" line="180"/>
-        <source>luff gores</source>
-        <translation type="unfinished"></translation>
+        <source>sections</source>
+        <translation> sezioni  </translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="183"/>
+        <location filename="../sailprinter.cpp" line="181"/>
+        <source>head gores</source>
+        <translation> altezza pannelli</translation>
+    </message>
+    <message>
+        <location filename="../sailprinter.cpp" line="182"/>
+        <source>luff gores</source>
+        <translation>ghindante pannelli</translation>
+    </message>
+    <message>
+        <location filename="../sailprinter.cpp" line="185"/>
         <source>Twist Foot Cut</source>
         <translation>Taglio twist foot</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="186"/>
+        <location filename="../sailprinter.cpp" line="188"/>
         <source>Vertical Cut</source>
         <translation>Taglio verticale</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="189"/>
+        <location filename="../sailprinter.cpp" line="191"/>
         <source>Mitre Cut</source>
         <translation>Taglio a spina di pesce</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="192"/>
+        <location filename="../sailprinter.cpp" line="194"/>
         <source>Sail layout</source>
         <translation>Taglio vela</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="195"/>
+        <location filename="../sailprinter.cpp" line="197"/>
         <source>Rig</source>
         <translation>Attrezzatura</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="196"/>
+        <location filename="../sailprinter.cpp" line="198"/>
         <source>Boat LOA</source>
         <translation>Lunghezza della barca</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="197"/>
+        <location filename="../sailprinter.cpp" line="199"/>
         <source>Mast/Luff rake</source>
         <translation>Inclinazione albero/ghindante</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="198"/>
+        <location filename="../sailprinter.cpp" line="200"/>
         <source>Tack position X</source>
         <translation>Posizione X del punto di mura</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="199"/>
+        <location filename="../sailprinter.cpp" line="201"/>
         <source>Tack height Y</source>
         <translation>Altezza Y del punto di mura</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="200"/>
+        <location filename="../sailprinter.cpp" line="202"/>
         <source>Fore triangle hoist I</source>
         <translation>Altezza I del triangolo di prua</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="201"/>
+        <location filename="../sailprinter.cpp" line="203"/>
         <source>Fore triangle base J</source>
         <translation>Base J del triangolo di prua</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="204"/>
+        <location filename="../sailprinter.cpp" line="206"/>
         <source>Sail dimensions</source>
         <translation>Dimensioni della vela</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="205"/>
+        <location filename="../sailprinter.cpp" line="207"/>
         <source>Luff length</source>
         <translation>Lunghezza del ghindante</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="206"/>
+        <location filename="../sailprinter.cpp" line="208"/>
         <source>Foot length</source>
         <translation>Lunghezza della base</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="207"/>
+        <location filename="../sailprinter.cpp" line="209"/>
         <source>Leech length</source>
         <translation>Lunghezza della balumina</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="208"/>
+        <location filename="../sailprinter.cpp" line="210"/>
         <source>Gaff length</source>
         <translation>Lunghezza del picco</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="209"/>
+        <location filename="../sailprinter.cpp" line="211"/>
         <source>Gaff angle wrt luff</source>
         <translation>Angolo tra picco e ghindante</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="212"/>
+        <location filename="../sailprinter.cpp" line="214"/>
         <source>Shape of edges</source>
         <translation>Forma dei bordi</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="213"/>
+        <location filename="../sailprinter.cpp" line="215"/>
         <source>Luff round</source>
         <translation>Allunamento del ghindante</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="214"/>
+        <location filename="../sailprinter.cpp" line="216"/>
         <source>Luff round position</source>
         <translation>Posizione allunamento ghindante</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="215"/>
+        <location filename="../sailprinter.cpp" line="217"/>
         <source>Foot round</source>
         <translation>Allunamento della base</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="216"/>
+        <location filename="../sailprinter.cpp" line="218"/>
         <source>Foot round position</source>
         <translation>Posizione allunamento base</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="217"/>
+        <location filename="../sailprinter.cpp" line="219"/>
         <source>Leech round</source>
         <translation>Allunamento della balumina</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="218"/>
+        <location filename="../sailprinter.cpp" line="220"/>
         <source>Leech round position</source>
         <translation>Posizione allunamento balumina</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="219"/>
+        <location filename="../sailprinter.cpp" line="221"/>
         <source>Gaff round</source>
         <translation>Allunamento del picco</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="220"/>
+        <location filename="../sailprinter.cpp" line="222"/>
         <source>Gaff round position</source>
         <translation>Posizione allunamento picco</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="223"/>
+        <location filename="../sailprinter.cpp" line="225"/>
         <source>Sail settings</source>
         <translation>Regolazioni vela</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="224"/>
+        <location filename="../sailprinter.cpp" line="226"/>
         <source>Twist angle</source>
         <translation>Angolo di svergolamento</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="225"/>
+        <location filename="../sailprinter.cpp" line="227"/>
         <source>Sheeting angle</source>
         <translation>Angolo caduta vela</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="228"/>
+        <location filename="../sailprinter.cpp" line="230"/>
         <source>Cloth seams and hems</source>
         <translation>Vivagni e vaine tessuto vela</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="229"/>
+        <location filename="../sailprinter.cpp" line="231"/>
         <source>Cloth width</source>
         <translation>Larghezza del tessuto vela</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="230"/>
+        <location filename="../sailprinter.cpp" line="232"/>
         <source>Seams width</source>
         <translation>Larghezza vivagni</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="231"/>
+        <location filename="../sailprinter.cpp" line="233"/>
         <source>Leech hem width</source>
         <translation>Larghezza vaina balumina</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="232"/>
+        <location filename="../sailprinter.cpp" line="234"/>
         <source>Other hem width</source>
-        <translation type="unfinished"></translation>
+        <translation>Larghezza altre vaine</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="235"/>
+        <location filename="../sailprinter.cpp" line="237"/>
         <source>Sail mould</source>
         <translation>Profilo della vela</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="236"/>
+        <location filename="../sailprinter.cpp" line="238"/>
         <source>Luff factor</source>
         <translation>Fattore ghindante</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="236"/>
+        <location filename="../sailprinter.cpp" line="238"/>
         <source>Depth</source>
         <translation>Profondita&apos;</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="236"/>
+        <location filename="../sailprinter.cpp" line="238"/>
         <source>Leech factor</source>
         <translation>Fattore balumina</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="238"/>
+        <location filename="../sailprinter.cpp" line="240"/>
         <source>Top profile</source>
         <translation>Profilo superiore</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="244"/>
+        <location filename="../sailprinter.cpp" line="246"/>
         <source>Mid profile at h = </source>
         <translation>Profilo mediano ad &quot;h&quot;</translation>
     </message>
     <message>
-        <location filename="../sailprinter.cpp" line="250"/>
+        <location filename="../sailprinter.cpp" line="252"/>
         <source>Bottom profile</source>
         <translation>Profilo inferiore</translation>
     </message>
@@ -2222,43 +2232,43 @@
     <message>
         <location filename="../sailviewer-tabs.cpp" line="64"/>
         <source>shaded view</source>
-        <translation type="unfinished">vista in chiaroscuro</translation>
+        <translation>vista in chiaroscuro</translation>
     </message>
     <message>
         <location filename="../sailviewer-tabs.cpp" line="66"/>
         <source>wireframe view</source>
-        <translation type="unfinished">vista spigoli</translation>
+        <translation>vista spigoli</translation>
     </message>
 </context>
 <context>
     <name>CWidgetProfile</name>
     <message>
-        <location filename="../widgetprofile.cpp" line="244"/>
+        <location filename="../widgetprofile.cpp" line="242"/>
         <source>%</source>
         <translation>%</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="242"/>
+        <location filename="../widgetprofile.cpp" line="240"/>
         <source>Luff shape</source>
         <translation>Forma ghindante</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="243"/>
+        <location filename="../widgetprofile.cpp" line="241"/>
         <source>Depth</source>
         <translation>Profondita&apos;</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="245"/>
+        <location filename="../widgetprofile.cpp" line="243"/>
         <source>Leech shape</source>
         <translation>Forma balumina</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="249"/>
+        <location filename="../widgetprofile.cpp" line="247"/>
         <source>degrees</source>
         <translation>gradi</translation>
     </message>
     <message>
-        <location filename="../widgetprofile.cpp" line="248"/>
+        <location filename="../widgetprofile.cpp" line="246"/>
         <source>cord</source>
         <translation>corda</translation>
     </message>
