@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2007 Robert & Jeremy Laine
+ * Copyright (C) 1993-2008 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,7 +39,7 @@
  * @param ptr pointer to the CProfile
  */
 CLabelProfile::CLabelProfile( QWidget *parent, CProfile *ptr)
-        : QLabel(parent), CDispArea(0.95), profile(ptr)
+        : QLabel(parent), profile(ptr), wasResized(true)
 {
     // set the background to white
     QPalette pal = palette();
@@ -56,16 +56,15 @@ void CLabelProfile::paintEvent( QPaintEvent *)
     QRect vRect = painter.viewport();
     painter.eraseRect(vRect);
 
+    CRect3d objRect;
+    objRect.max = CPoint3d(1 , 0.2);
+
     if ( wasResized )
     {
         CRect3d viewRect;
         viewRect.max = CPoint3d(vRect.width() , vRect.height());
 
-        CRect3d objRect;
-        objRect.max = CPoint3d(1 , 0.2);
-        center = objRect.center();
-
-        lRect = calcLRect(viewRect , objRect);
+        lRect = calcLRect(viewRect , objRect, objRect.center(), 0.95);
         wasResized = 0;
     }
 
@@ -76,13 +75,13 @@ void CLabelProfile::paintEvent( QPaintEvent *)
     real scale =  vRect.height() / lRect.height();
 
     // do a translation to have from z=0 to z=scale centered
-    painter.translate( (lRect.width() / 2 - center.x()) * scale,  vRect.height() + (center.y() - lRect.height()/2) * scale );
+    painter.translate( (lRect.width() / 2 - objRect.center().x()) * scale,  vRect.height() + (objRect.center().y() - lRect.height()/2) * scale );
 
     // flip coordinate system to have the z axis pointing up
     painter.scale(1,-1);
 
     prev = QPoint( 0 , int(scale * profile->z(0) ) );
-    for( unsigned i = 1; i < nbpoints; i++)
+    for (unsigned i = 1; i < nbpoints; i++)
     {
         x = real(i) / (nbpoints -1);
         z = profile->z(x);
@@ -143,7 +142,7 @@ CWidgetProfile::CWidgetProfile( QWidget *parent, CProfile *ptr,
     spinBoxesLayout->addWidget( lblLuff );
 
     spinLuff = new QSpinBox( grpProfile );
-    spinLuff->setMaximum( 16 );
+    spinLuff->setMaximum( 18 );
     spinLuff->setMinimum( 1 );
     spinLuff->setValue( 1 );
     spinBoxesLayout->addWidget( spinLuff );
@@ -156,7 +155,7 @@ CWidgetProfile::CWidgetProfile( QWidget *parent, CProfile *ptr,
     spinBoxesLayout->addWidget( lblDepth );
 
     spinDepth = new QSpinBox( grpProfile );
-    spinDepth->setMaximum( 20 );
+    spinDepth->setMaximum( 22 );
     spinDepth->setMinimum( 1 );
     spinDepth->setValue( 10 );
     spinBoxesLayout->addWidget( spinDepth );
@@ -172,7 +171,7 @@ CWidgetProfile::CWidgetProfile( QWidget *parent, CProfile *ptr,
 
     spinLeech = new QSpinBox( grpProfile );
     spinLeech->setMinimum( -4 );
-    spinLeech->setMaximum( 14 );
+    spinLeech->setMaximum( 20 );
     spinBoxesLayout->addWidget( spinLeech );
 
     grpProfileLayout->addLayout( spinBoxesLayout, 1, 0 );
@@ -223,11 +222,11 @@ CWidgetProfile::CWidgetProfile( QWidget *parent, CProfile *ptr,
     connect( spinDepth, SIGNAL( valueChanged(int) ), this, SLOT( slotChanged() ) );
     connect( spinLeech, SIGNAL( valueChanged(int) ), this, SLOT( slotChanged() ) );
 
-    // set translations and trigger update 
+    // set translations and trigger update
     // NOTE : all the widgets need to be created before doing this
     languageChange();
     resize( QSize(527, 159).expandedTo( minimumSizeHint() ) );
-    
+
     // trigger the computation of profile to update the ancillary data labels
     slotChanged();
 }
@@ -245,7 +244,7 @@ void CWidgetProfile::languageChange()
     // ancillary data labels
     lblLuffSlopeDegrees->setText( tr( "degrees" ) );
     lblMaxPosCord->setText( tr( "cord") );
-    lblLeechSlopeDegrees->setText( tr( "degrees" ) );    
+    lblLeechSlopeDegrees->setText( tr( "degrees" ) );
 }
 
 
@@ -261,7 +260,7 @@ void CWidgetProfile::slotChanged()
 
     // update profile view
     lblDraw->update();
-    // display the position of the maximum depth 
+    // display the position of the maximum depth
     lblLuffSlopeValue->setText( QString::number ( int( 57.29579 * atan(profile->slope(0.0)) ) ));
     lblMaxPosValue->setText( QString::number (profile->getMaxPos() ) );
     lblLeechSlopeValue->setText( QString::number ( int( 57.29579 * atan(profile->slope(1.0)) ) ) );
